/*
 * system.h
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 */

#ifndef kern_system_h
#define kern_system_h

#ifndef ASM_FILE

extern int sys_reboot(int);
extern int sys_uname();

#endif //ASM_FILE

#endif //kern_system_h
